#ifndef faceblox_h
#define faceblox_h

// Define the default number of devices we have in the chain
#define MAX_DEVICES 2

// NOTE: CLK and DATA are hard-wired if using the SPI port.  Pin 12 is MISO and becomes unusable
#define CLK_PIN   13  // or SCK
#define DATA_PIN  11  // or MOSI
#define DIN_PIN  12  // or MISO - Pin 12 is MISO and becomes unusable (both hard and soft)
#define CS_PIN    8  // or SS

#include "MD_MAX72xx.h"


class FaceBloX : public MD_MAX72XX
{
  public:
    FaceBloX(); 
    FaceBloX(uint8_t numDisplays); 

    //Load a bitmap (8x16) image onto the display
    //Each byte represents a column (a0=left most, h1=right most)
    //If only one display is connected then only the right half of the image will be displayed (a1-h1)
    void picture(byte a0, byte b0, byte c0, byte d0, byte e0, byte f0, byte g0, byte h0,
                 byte a1, byte b1, byte c1, byte d1, byte e1, byte f1, byte g1, byte h1);
    void picture(byte* bitmap);
	void picture();	


    //Scrolls a message synchronously (the whole message will be displayed before returning)
    //scrollSpeed: ms between scrolling a column. 0=no movement (beginning of message will be loaded, then return)
    //charSpacing: number of blank columns between characters
    bool scrollText(const char *message, uint8_t scrollSpeed, uint8_t charSpacing);
    bool scrollText(String message, uint8_t scrollSpeed, uint8_t charSpacing);
	bool scrollText(double message, uint8_t scrollSpeed, uint8_t charSpacing);
	//bool scrollText(long int message, uint8_t scollDelay, uint8_t charSpacing);

	
	//Shows a message (If the message is larger than the display only the first part will be displayed)
    //charSpacing: number of blank columns between characters
    bool showText(const char *message, uint8_t charSpacing);
	
	//Scrolls a message asynchronously (this method must be called repeatedly)
    //scrollDelay: ms between scrolling a column. 0=no movement
    //charSpacing: number of blank columns between characters
    bool scrollTextASync(const char *message, uint32_t scrollDelay, uint8_t charSpacing);

};

#endif
